summaryrefslogtreecommitdiffstats
path: root/Utilities/cmcurl/lib/smtp.h
diff options
context:
space:
mode:
Diffstat (limited to 'Utilities/cmcurl/lib/smtp.h')
-rw-r--r--Utilities/cmcurl/lib/smtp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/Utilities/cmcurl/lib/smtp.h b/Utilities/cmcurl/lib/smtp.h
index 9fbe0c5..b67340a 100644
--- a/Utilities/cmcurl/lib/smtp.h
+++ b/Utilities/cmcurl/lib/smtp.h
@@ -11,7 +11,7 @@
*
* This software is licensed as described in the file COPYING, which
* you should have received as part of this distribution. The terms
- * are also available at http://curl.haxx.se/docs/copyright.html.
+ * are also available at https://curl.haxx.se/docs/copyright.html.
*
* You may opt to use, copy, modify, merge, publish, distribute and/or sell
* copies of the Software, and permit persons to whom the Software is
@@ -47,9 +47,9 @@ typedef enum {
SMTP_LAST /* never used */
} smtpstate;
/* This SMTP struct is used in the SessionHandle. All SMTP data that is
connection-oriented must be in smtp_conn to properly deal with the fact that
- perhaps the SessionHandle is changed between the times the connection is
+ perhaps the Curl_easy is changed between the times the connection is
used. */
struct SMTP {
curl_pp_transfer transfer;
@@ -47,9 +47,9 @@ typedef enum {
SMTP_LAST /* never used */
} smtpstate;
-/* This SMTP struct is used in the SessionHandle. All SMTP data that is
+/* This SMTP struct is used in the Curl_easy. All SMTP data that is
connection-oriented must be in smtp_conn to properly deal with the fact that